@@ -135,6 +135,61 @@ function get_button_options(buttons, editor) {
     return button_options;
 }
 
+/**
+ * render edit icon, for row editing
+ *
+ * column declaration for CrudApi must be
+ *
+ *      {'data': '',  # needs to be '' else get exception converting options from meetings render_template
+ *       # TypeError: '<' not supported between instances of 'str' and 'NoneType'
+ *       'name': 'edit-control',
+ *       'className': 'edit-control shrink-to-fit',
+ *       'orderable': False,
+ *       'defaultContent': '',
+ *       'label': '',
+ *       'type': 'hidden',  # only affects editor modal
+ *       # this heading title or some other title like "Edit"
+ *       'title': '<i class="fas fa-edit" aria-hidden="true"></i>',
+ *       'render': {'eval': 'render_edit'},
+ *       },
+ *
+ * @returns {string}
+ */
+function render_edit() {
+    return '<i class="fas fa-edit" aria-hidden="true"></i>';
+}
+
+/**
+ * render a fontawesome icon
+ *
+ * @param iconclass - classes of icon, e.g., "fas fa-edit"
+ * @returns {function(): string} - string is rendered text
+ */
+function render_icon(iconclass) {
+    var fn = function() {
+        return '<i class="' + iconclass + '" aria-hidden="true"></i>';
+    }
+    return fn;
+}
+
+/**
+ * create click event handler for indicated datatable, cell
+ * when cell clicked, row is selected and button_name'd button is triggered (pressed)
+ *
+ * @param dt - datatable
+ * @param cell_select - e.g., 'td.colclass'
+ * @param button_name - name attached to datatable button to "press"
+ */
+function onclick_trigger(dt, cell_select, button_name) {
+    dt.on('click', cell_select, function (e) {
+        var tr = $(this).closest('tr');
+        var row = dt.row(tr);
+        row.select();
+        dt.buttons(button_name + ':name').trigger();
+        e.stopPropagation();
+    });
+}
+
 /**
  * configure dataTables for table with id=datatable
  *
